nmw_report_resid: Generate Residual Diagnostics Report (S4-Residuals.PDF)

View source: R/report_resid.R

nmw_report_residR Documentation

Generate Residual Diagnostics Report (S4-Residuals.PDF)

Description

Generates a PDF report with WRES, CWRES, IWRES diagnostics including scatter plots, histograms, normality tests, binomial count tests, and individual residual curves with run tests.

Usage

nmw_report_resid(run_dir = getwd())

Arguments

run_dir

character, path to the NONMEM run directory (default: current directory)


nmw documentation built on May 8, 2026, 9:07 a.m.