| nmw_report_resid | R Documentation |
Generates a PDF report with WRES, CWRES, IWRES diagnostics including scatter plots, histograms, normality tests, binomial count tests, and individual residual curves with run tests.
nmw_report_resid(run_dir = getwd())
run_dir |
character, path to the NONMEM run directory (default: current directory) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.