Learn R Programming

nmw (version 0.3.0)

nmw_report_resid: Generate Residual Diagnostics Report (S4-Residuals.PDF)

Description

Generates a PDF report with WRES, CWRES, IWRES diagnostics including scatter plots, histograms, normality tests, binomial count tests, and individual residual curves with run tests.

Usage

nmw_report_resid(run_dir = getwd())

Arguments

run_dir

character, path to the NONMEM run directory (default: current directory)